# Package citation

If you use this package please cite the following publication
```
@INPROCEEDINGS{11230700,
    author={Zancanaro, Alberto and Badia, Leonardo and Cisotto, Giulia},
    booktitle={2025 IEEE Conference on Standards for Communications and Networking (CSCN)}, 
    title={BlockDTW: Efficient and Scalable Similarity Search Algorithm for Healthcare-Focused Time-Series}, 
    year={2025},
    volume={},
    number={},
    pages={1-6},
    keywords={Training;Accuracy;Uncertainty;Stochastic processes;Distortion;Brain modeling;Electroencephalography;Real-time systems;Digital twins;Complexity theory;Medical digital twins;Time series;Dynamic time warping;Similarity search;EEG;Deep learning},
    doi={10.1109/CSCN67557.2025.11230700}}
```

## SDTW Citation

If you use softDTW please also cite the following works, based on the implementation you decide to use.

### `mag`
One of most popular and used SDTW implementations available on the web, created by Mehran Maghoumi.
You can find the original repo here https://github.com/Maghoumi/pytorch-softdtw-cuda
```
@phdthesis{maghoumi2020dissertation,
    title={{Deep Recurrent Networks for Gesture Recognition and Synthesis}},
    author={Mehran Maghoumi},
    year={2020},
    school={University of Central Florida Orlando, Florida}
}

@inproceedings{maghoumi2021deepnag,
    title={DeepNAG: Deep Non-Adversarial Gesture Generation},
    author={Maghoumi, Mehran and Taranta, Eugene Matthew and LaViola, Joseph},
    booktitle={26th International Conference on Intelligent User Interfaces},
    pages={213--223},
    year={2021}
}
```


### `pysdtw`

SDTW implementation by Antoine Loriette. Also available on PyPi.

To the best of our knowledge no paper or any other work was mentioned in the GitHub page and PyPi page of this SDTW implementation.
- GitHub repo : https://github.com/toinsson/pysdtw
- PyPi Page : https://pypi.org/project/pysdtw/

### `ron` 
Very efficient and modern implementation of SoftDTW by Ron Shapira Weber.
You can find the original repo at https://github.com/BGU-CS-VIL/sdtw-cuda-torch

```
@misc{weber2026softdtwcudatorchmemoryefficientgpuacceleratedsoft,
    title={SoftDTW-CUDA-Torch: Memory-Efficient GPU-Accelerated Soft Dynamic Time Warping for PyTorch}, 
    author={Ron Shapira Weber and Oren Freifeld},
    year={2026},
    eprint={2602.17206},
    archivePrefix={arXiv},
    primaryClass={cs.LG},
    url={https://arxiv.org/abs/2602.17206}, 
}

@InProceedings{pmlr-v267-shapira-weber25a,
    title = 	 {{T}ime{P}oint: Accelerated Time Series Alignment via Self-Supervised Keypoint and Descriptor Learning},
    author =       {Shapira Weber, Ron and Benishay, Shahar and Lavrinenko, Andrey and Finder, Shahaf E. and Freifeld, Oren},
    booktitle = 	 {Proceedings of the 42nd International Conference on Machine Learning},
    pages = 	 {54275--54299},
    year = 	 {2025},
    editor = 	 {Singh, Aarti and Fazel, Maryam and Hsu, Daniel and Lacoste-Julien, Simon and Berkenkamp, Felix and Maharaj, Tegan and Wagstaff, Kiri and Zhu, Jerry},
    volume = 	 {267},
    series = 	 {Proceedings of Machine Learning Research},
    month = 	 {13--19 Jul},
    publisher =    {PMLR},
    pdf = 	 {https://raw.githubusercontent.com/mlresearch/v267/main/assets/shapira-weber25a/shapira-weber25a.pdf},
    url = 	 {https://proceedings.mlr.press/v267/shapira-weber25a.html},
    abstract = 	 {Fast and scalable alignment of time series is a fundamental challenge in many domains. The standard solution, Dynamic Time Warping (DTW), struggles with poor scalability and sensitivity to noise. We introduce TimePoint, a self-supervised method that dramatically accelerates DTW-based alignment while typically improving alignment accuracy by learning keypoints and descriptors from synthetic data. Inspired by 2D keypoint detection but carefully adapted to the unique challenges of 1D signals, TimePoint leverages efficient 1D diffeomorphisms, which effectively model nonlinear time warping, to generate realistic training data. This adaptation, along with fully convolutional and wavelet convolutional architectures, enables the extraction of informative keypoints and descriptors. Applying DTW to these sparse representations yields major speedups and typically higher alignment accuracy than standard DTW applied to the full signals. Despite being trained solely on synthetic data, TimePoint generalizes well to real-world time series. Extensive experiments demonstrate that TimePoint consistently achieves faster and more accurate alignments than standard DTW, making it a scalable solution for time-series analysis. Our code is available at https://github.com/ BGU-CS-VIL/TimePoint.}
}
```
